@@ -1,4 +1,4 @@
-from typing import Callable, Iterable, Optional
+from typing import Callable, Iterable
 
 from .text_alignment_collection import TextAlignmentCollection
 from .text_alignment_corpus import TextAlignmentCorpus
@@ -13,14 +13,14 @@ class FilteredTextAlignmentCorpus(TextAlignmentCorpus):
     def text_alignment_collections(self) -> Iterable[TextAlignmentCollection]:
         return (c for c in self._corpus.text_alignment_collections if self._filter(c))
 
-    def get_text_alignment_collection(self, id: str) -> Optional[TextAlignmentCollection]:
-        collection = self._corpus.get_text_alignment_collection(id)
-        if collection is not None and self._filter(collection):
+    def __getitem__(self, id: str) -> TextAlignmentCollection:
+        collection = self._corpus[id]
+        if self._filter(collection):
             return collection
-        return None
+        return self.create_null_text_alignment_collection(id)
+
+    def create_null_text_alignment_collection(self, id: str) -> TextAlignmentCollection:
+        return self._corpus.create_null_text_alignment_collection(id)
 
     def invert(self) -> "FilteredTextAlignmentCorpus":
         return FilteredTextAlignmentCorpus(self._corpus.invert(), self._filter)
-
-    def get_text_alignment_collection_sort_key(self, id: str) -> str:
-        return self._corpus.get_text_alignment_collection_sort_key(id)
