@@ -5,7 +5,6 @@ from ..scripture.verse_ref import VerseRef
 from ..utils.comparable import compare
 from ..utils.context_managed_generator import ContextManagedGenerator
 from .aligned_word_pair import AlignedWordPair
-from .null_text_alignment_collection import NullTextAlignmentCollection
 from .parallel_text_segment import ParallelTextSegment
 from .text import Text
 from .text_alignment import TextAlignment
@@ -47,15 +46,11 @@ class RangeInfo:
 
 class ParallelText:
     def __init__(
-        self, source_text: Text, target_text: Text, text_alignment_collection: Optional[TextAlignmentCollection] = None
+        self, source_text: Text, target_text: Text, text_alignment_collection: TextAlignmentCollection
     ) -> None:
         self._source_text = source_text
         self._target_text = target_text
-        self._text_alignment_collection = (
-            NullTextAlignmentCollection(source_text.id, source_text.sort_key)
-            if text_alignment_collection is None
-            else text_alignment_collection
-        )
+        self._text_alignment_collection = text_alignment_collection
 
     @property
     def id(self) -> str:
@@ -89,8 +84,8 @@ class ParallelText:
     def _get_segments(
         self, all_source_segments: bool, all_target_segments: bool, include_text: bool
     ) -> Generator[ParallelTextSegment, None, None]:
-        with self._source_text.get_segments(include_text) as src_iterator, self._target_text.get_segments(
-            include_text
+        with self._source_text.get_segments(include_text) as src_iterator, self._target_text.get_segments_based_on(
+            self._source_text, include_text
         ) as trg_iterator, self._text_alignment_collection.alignments as alignment_iterator:
             range_info = RangeInfo(self)
             source_same_ref_segments: List[TextSegment] = []
