@@ -1,8 +1,10 @@
+from abc import abstractmethod
 from typing import Generator, Optional
 
 from ..scripture.verse_ref import VerseRef, Versification
 from ..tokenization.tokenizer import Tokenizer
 from .scripture_text import ScriptureText
+from .stream_container import StreamContainer
 from .text_segment import TextSegment
 from .usx_verse_parser import UsxVerseParser
 
@@ -12,9 +14,12 @@ class UsxTextBase(ScriptureText):
         self, word_tokenizer: Tokenizer[str, int, str], id: str, versification: Optional[Versification]
     ) -> None:
         super().__init__(word_tokenizer, id, versification)
-
         self._parser = UsxVerseParser()
 
+    @abstractmethod
+    def _create_stream_container(self) -> StreamContainer:
+        ...
+
     def _get_segments(self, include_text: bool) -> Generator[TextSegment, None, None]:
         with self._create_stream_container() as stream_container, stream_container.open_stream() as stream:
             prev_verse_ref = VerseRef()
